@@ -29,7 +29,7 @@
 #include <KLocalizedString>
 
 #include <QDebug>
-#include <QtCore/QSocketNotifier>
+#include <QSocketNotifier>
 #include <poll.h>
 #include <KConfigGroup>
 
@@ -65,7 +65,7 @@ PendingInvitationsRfbClient::~PendingInvitationsRfbClient()
 
 void PendingInvitationsRfbClient::processNewClient()
 {
-    QString host = peerAddress(m_rfbClient->sock) + ":" + QString::number(peerPort(m_rfbClient->sock));
+    QString host = peerAddress(m_rfbClient->sock) + ':' + QString::number(peerPort(m_rfbClient->sock));
 
     if (d->askOnConnect == false) {
 
@@ -79,7 +79,7 @@ void PendingInvitationsRfbClient::processNewClient()
                             i18n("Received connection from %1, on hold (waiting for confirmation)",
                                 host));
 
-        InvitationsConnectionDialog *dialog = new InvitationsConnectionDialog(0);
+        InvitationsConnectionDialog *dialog = new InvitationsConnectionDialog(nullptr);
         dialog->setRemoteHost(host);
         dialog->setAllowRemoteControl(KrfbConfig::allowDesktopControl());
 
@@ -126,7 +126,7 @@ void PendingInvitationsRfbClient::onSocketActivated()
 bool PendingInvitationsRfbClient::checkPassword(const QByteArray & encryptedPassword)
 {
     QByteArray password ;
-    qDebug() << "about to start autentication";
+    qDebug() << "about to start authentication";
 
     if(InvitationsRfbServer::instance->allowUnattendedAccess() && vncAuthCheckPassword(
             InvitationsRfbServer::instance->unattendedPassword().toLocal8Bit(),
@@ -149,5 +149,3 @@ void PendingInvitationsRfbClient::dialogAccepted()
     client->setControlEnabled(dialog->allowRemoteControl());
     accept(client);
 }
-
-#include "invitationsrfbclient.moc"
